// Decompiled by JEB v1.4.201311020 - http://www.android-decompiler.com

package com.google.gson.stream;

import java.io.Closeable;
import java.io.Flushable;
import java.io.IOException;
import java.io.Writer;
import java.util.ArrayList;
import java.util.List;

public class JsonWriter implements Closeable, Flushable {
    private static final String[] HTML_SAFE_REPLACEMENT_CHARS;
    private static final String[] REPLACEMENT_CHARS;
    private String deferredName;
    private boolean htmlSafe;
    private String indent;
    private boolean lenient;
    private final Writer out;
    private String separator;
    private boolean serializeNulls;
    private final List stack;

    static  {
        JsonWriter.REPLACEMENT_CHARS = new String[128];
        int v0;
        for(v0 = 0; v0 <= 31; ++v0) {
            JsonWriter.REPLACEMENT_CHARS[v0] = String.format("\\u%04x", Integer.valueOf(v0));
        }

        JsonWriter.REPLACEMENT_CHARS[34] = "\\\"";
        JsonWriter.REPLACEMENT_CHARS[92] = "\\\\";
        JsonWriter.REPLACEMENT_CHARS[9] = "\\t";
        JsonWriter.REPLACEMENT_CHARS[8] = "\\b";
        JsonWriter.REPLACEMENT_CHARS[10] = "\\n";
        JsonWriter.REPLACEMENT_CHARS[13] = "\\r";
        JsonWriter.REPLACEMENT_CHARS[12] = "\\f";
        JsonWriter.HTML_SAFE_REPLACEMENT_CHARS = JsonWriter.REPLACEMENT_CHARS.clone();
        JsonWriter.HTML_SAFE_REPLACEMENT_CHARS[60] = "\\u003c";
        JsonWriter.HTML_SAFE_REPLACEMENT_CHARS[62] = "\\u003e";
        JsonWriter.HTML_SAFE_REPLACEMENT_CHARS[38] = "\\u0026";
        JsonWriter.HTML_SAFE_REPLACEMENT_CHARS[61] = "\\u003d";
        JsonWriter.HTML_SAFE_REPLACEMENT_CHARS[39] = "\\u0027";
    }

    public JsonWriter(Writer out) {
        super();
        this.stack = new ArrayList();
        this.stack.add(JsonScope.EMPTY_DOCUMENT);
        this.separator = ":";
        this.serializeNulls = true;
        if(out == null) {
            throw new NullPointerException("out == null");
        }

        this.out = out;
    }

    private void beforeName() throws IOException {
        JsonScope v0 = this.peek();
        if(v0 == JsonScope.NONEMPTY_OBJECT) {
            this.out.write(44);
        }
        else if(v0 != JsonScope.EMPTY_OBJECT) {
            throw new IllegalStateException("Nesting problem: " + this.stack);
        }

        this.newline();
        this.replaceTop(JsonScope.DANGLING_NAME);
    }

    private void beforeValue(boolean root) throws IOException {
        switch(com.google.gson.stream.JsonWriter$1.$SwitchMap$com$google$gson$stream$JsonScope[this.peek().ordinal()]) {
            case 1: {
                goto label_13;
            }
            case 2: {
                goto label_18;
            }
            case 3: {
                goto label_27;
            }
            case 4: {
                goto label_31;
            }
            case 5: {
                goto label_36;
            }
        }

        throw new IllegalStateException("Nesting problem: " + this.stack);
    label_36:
        this.out.append(this.separator);
        this.replaceTop(JsonScope.NONEMPTY_OBJECT);
        return;
    label_27:
        this.replaceTop(JsonScope.NONEMPTY_ARRAY);
        this.newline();
        return;
    label_31:
        this.out.append(',');
        this.newline();
        return;
    label_13:
        if(!this.lenient) {
            throw new IllegalStateException("JSON must have only one top-level value.");
        label_18:
        }

        if(!this.lenient && !root) {
            throw new IllegalStateException("JSON must start with an array or an object.");
        }

        this.replaceTop(JsonScope.NONEMPTY_DOCUMENT);
    }

    public JsonWriter beginArray() throws IOException {
        this.writeDeferredName();
        return this.open(JsonScope.EMPTY_ARRAY, "[");
    }

    public JsonWriter beginObject() throws IOException {
        this.writeDeferredName();
        return this.open(JsonScope.EMPTY_OBJECT, "{");
    }

    private JsonWriter close(JsonScope empty, JsonScope nonempty, String closeBracket) throws IOException {
        JsonScope v0 = this.peek();
        if(v0 != nonempty && v0 != empty) {
            throw new IllegalStateException("Nesting problem: " + this.stack);
        }

        if(this.deferredName != null) {
            throw new IllegalStateException("Dangling name: " + this.deferredName);
        }

        this.stack.remove(this.stack.size() - 1);
        if(v0 == nonempty) {
            this.newline();
        }

        this.out.write(closeBracket);
        return this;
    }

    public void close() throws IOException {
        this.out.close();
        int v0 = this.stack.size();
        if(v0 <= 1 && (v0 != 1 || this.stack.get(v0 - 1) == JsonScope.NONEMPTY_DOCUMENT)) {
            this.stack.clear();
            return;
        }

        throw new IOException("Incomplete document");
    }

    public JsonWriter endArray() throws IOException {
        return this.close(JsonScope.EMPTY_ARRAY, JsonScope.NONEMPTY_ARRAY, "]");
    }

    public JsonWriter endObject() throws IOException {
        return this.close(JsonScope.EMPTY_OBJECT, JsonScope.NONEMPTY_OBJECT, "}");
    }

    public void flush() throws IOException {
        if(this.stack.isEmpty()) {
            throw new IllegalStateException("JsonWriter is closed.");
        }

        this.out.flush();
    }

    public final boolean getSerializeNulls() {
        return this.serializeNulls;
    }

    public boolean isLenient() {
        return this.lenient;
    }

    public JsonWriter name(String name) throws IOException {
        if(name == null) {
            throw new NullPointerException("name == null");
        }

        if(this.deferredName != null) {
            throw new IllegalStateException();
        }

        if(this.stack.isEmpty()) {
            throw new IllegalStateException("JsonWriter is closed.");
        }

        this.deferredName = name;
        return this;
    }

    private void newline() throws IOException {
        if(this.indent != null) {
            this.out.write("\n");
            int v0;
            for(v0 = 1; v0 < this.stack.size(); ++v0) {
                this.out.write(this.indent);
            }
        }
    }

    public JsonWriter nullValue() throws IOException {
        if(this.deferredName == null) {
        label_5:
            this.beforeValue(false);
            this.out.write("null");
        }
        else if(this.serializeNulls) {
            this.writeDeferredName();
            goto label_5;
        }
        else {
            this.deferredName = null;
        }

        return this;
    }

    private JsonWriter open(JsonScope empty, String openBracket) throws IOException {
        this.beforeValue(true);
        this.stack.add(empty);
        this.out.write(openBracket);
        return this;
    }

    private JsonScope peek() {
        int v0 = this.stack.size();
        if(v0 == 0) {
            throw new IllegalStateException("JsonWriter is closed.");
        }

        return this.stack.get(v0 - 1);
    }

    private void replaceTop(JsonScope topOfStack) {
        this.stack.set(this.stack.size() - 1, topOfStack);
    }

    public final void setLenient(boolean lenient) {
        this.lenient = lenient;
    }

    private void string(String value) throws IOException {
        String v4;
        String[] v5;
        if(this.htmlSafe) {
            v5 = JsonWriter.HTML_SAFE_REPLACEMENT_CHARS;
        }
        else {
            v5 = JsonWriter.REPLACEMENT_CHARS;
        }

        this.out.write("\"");
        int v2 = 0;
        int v3 = value.length();
        int v1;
        for(v1 = 0; v1 < v3; ++v1) {
            int v0 = value.charAt(v1);
            if(v0 < 128) {
                v4 = v5[v0];
                if(v4 != null) {
                    goto label_22;
                }
            }
            else if(v0 == 8232) {
                v4 = "\\u2028";
                goto label_22;
            }
            else if(v0 == 8233) {
                v4 = "\\u2029";
            label_22:
                if(v2 < v1) {
                    this.out.write(value, v2, v1 - v2);
                }

                this.out.write(v4);
                v2 = v1 + 1;
            }
        }

        if(v2 < v3) {
            this.out.write(value, v2, v3 - v2);
        }

        this.out.write("\"");
    }

    public JsonWriter value(Number value) throws IOException {
        if(value == null) {
            this = this.nullValue();
        }
        else {
            this.writeDeferredName();
            String v0 = value.toString();
            if(!this.lenient && ((v0.equals("-Infinity")) || (v0.equals("Infinity")) || (v0.equals("NaN")))) {
                throw new IllegalArgumentException("Numeric values must be finite, but was " + value);
            }

            this.beforeValue(false);
            this.out.append(((CharSequence)v0));
        }

        return this;
    }

    public JsonWriter value(String value) throws IOException {
        if(value == null) {
            this = this.nullValue();
        }
        else {
            this.writeDeferredName();
            this.beforeValue(false);
            this.string(value);
        }

        return this;
    }

    public JsonWriter value(long value) throws IOException {
        this.writeDeferredName();
        this.beforeValue(false);
        this.out.write(Long.toString(value));
        return this;
    }

    public JsonWriter value(boolean value) throws IOException {
        String v0;
        this.writeDeferredName();
        this.beforeValue(false);
        Writer v1 = this.out;
        if(value) {
            v0 = "true";
        }
        else {
            v0 = "false";
        }

        v1.write(v0);
        return this;
    }

    private void writeDeferredName() throws IOException {
        if(this.deferredName != null) {
            this.beforeName();
            this.string(this.deferredName);
            this.deferredName = null;
        }
    }
}

